==> openGion_dev_5.7.8.0.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GEA05S.sql <==
/****************************************************************************/
/* GEA05 ( ﾛｰﾙﾏｽﾀ )                                                         */
/*                                                                          */
/* Created : 2014/06/13 18:57:36                                            */
/****************************************************************************/
CREATE TABLE GEA05 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , ROLES        VARCHAR2 ( 500 )                    NOT NULL            /*  20 ﾛｰﾙｽﾞ    */
 , NMROLE       VARCHAR2 ( 200 )                                        /*  30 ﾛｰﾙ名称  */
 , KBROLE       VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /*  40 ﾛｰﾙ区分  */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GEA05S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GEA05T00 
  BEFORE INSERT ON GEA05
  FOR EACH ROW 
  BEGIN 
    SELECT GEA05S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion_dev_5.9.32.0.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GEA05S.sql <==
/****************************************************************************/
/* GEA05 ( ﾛｰﾙﾏｽﾀ )                                                         */
/*                                                                          */
/* Created : 2018/05/02 11:51:56                                            */
/****************************************************************************/
CREATE TABLE GEA05 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , ROLES        VARCHAR2 ( 500 )                    NOT NULL            /*  20 ﾛｰﾙｽﾞ    */
 , NMROLE       VARCHAR2 ( 200 )                                        /*  30 ﾛｰﾙ名称  */
 , KBROLE       VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /*  40 ﾛｰﾙ区分  */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GEA05S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GEA05T00 
  BEFORE INSERT ON GEA05
  FOR EACH ROW 
  BEGIN 
    SELECT GEA05S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
